@@ -11,10 +11,10 @@ has '_invalids' => (
     isa => 'HashRef',
     default => sub { {} },
     provides => {
-        set     => 'set_invalid',
-        get     => 'is_invalid',
+        count   => 'invalid_count',
+        exists  => 'is_invalid',
         keys    => 'invalids',
-        count   => 'invalid_count'
+        set     => 'set_invalid',
     }
 );
 
@@ -24,24 +24,47 @@ has '_missings' => (
     isa => 'HashRef',
     default => sub { {} },
     provides => {
-        set     => 'set_missing',
-        get     => 'is_missing',
+        count   => 'missing_count',
+        exists  => 'is_missing',
         keys    => 'missings',
-        count   => 'missing_count'
+        set     => 'set_missing',
     }
 );
 
-has 'values' => (
+has '_values' => (
     metaclass => 'Collection::Hash',
     is => 'rw',
     isa => 'HashRef',
     default => sub { {} },
     provides => {
+        count   => 'value_count',
+        delete  => 'delete_value',
+        exists  => 'is_valid',
         get     => 'get_value',
+        keys    => 'values',
         set     => 'set_value',
     }
 );
 
+__PACKAGE__->meta->add_method('valids' => __PACKAGE__->can('values'));
+__PACKAGE__->meta->add_method('valid_count' => __PACKAGE__->can('value_count'));
+
+sub merge {
+    my ($self, $other) = @_;
+
+    foreach my $i ($other->invalids) {
+        $self->set_invalid($i, 1);
+    }
+
+    foreach my $m ($other->missings) {
+        $self->set_missing($m, 1);
+    }
+
+    foreach my $k ($other->valids) {
+        $self->set_value($k, $other->get_value($k));
+    }
+}
+
 sub success {
     my ($self) = @_;
 
@@ -102,18 +125,41 @@ Returns true or false based on if the verification's success.
 =head1 VALUES
 
 The values present in the result are the filtered, valid values.  These may
-differ from the ones supplied to the verify method.
+differ from the ones supplied to the verify method due to either filters
+or coercions.
+
+=head2 valid_count
+
+Returns the number of valid fields in this Results.
 
 =head2 values
 
 Returns a hashref of all the fields this profiled verified as the keys and
 the values that remain after verification.
 
+=head2 delete_value ($name)
+
+Deletes the specified value from the results.
+
 =head2 get_value ($name)
 
 Returns the value for the specified field.  The value may be different from
 the one originally supplied due to filtering or coercion.
 
+=head2 value_count
+
+Returns the number of values in this Results.
+
+=head1 VALID FIELDS
+
+=head2 is_valid ($name)
+
+Returns true if the field is valid.
+
+=head2 valids
+
+Returns a list of keys for which we have valid values.
+
 =head1 INVALID FIELDS
 
 =head2 is_invalid ($name)
